<?php

namespace Drupal\geoportail_map\Plugin\Field\FieldFormatter;

use Drupal\Core\Annotation\Translation;
use Drupal\Core\Field\Annotation\FieldFormatter;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'geoportail_map' formatter.
 *
 * @FieldFormatter(
 *   id = "geoportail_map",
 *   label = @Translation("Geoportail Map"),
 *   field_types = {
 *     "geofield"
 *   }
 * )
 */
class GeoportailMapFormatter extends FormatterBase
{
    /**
     * {@inheritdoc}
     */
    public static function defaultSettings() {
        return [
                'bglayer' => 'basemap_2015_global',
                'layers' => 'addresses',
                'zoom' => 18,
                'langcode' => 'en',
            ] + parent::defaultSettings();
    }
    /**
     * {@inheritdoc}
     */
    public function settingsForm(array $form, FormStateInterface $form_state)
    {
        $elements = [];
        $elements = parent::settingsForm($form, $form_state);

        $elements['bglayer'] = [
            '#type' => 'textfield',
            '#title' => t('The Id of the background layer'),
            '#default_value' => $this->getSetting('bglayer'),
        ];
        $elements['layers'] = [
            '#type' => 'select',
            '#title' => t('The Id of the overlay layer'),
            '#options' => [
                '' => t('No overlay'),
                'addresses' => t('Addresses'),
                'cdt_lignes_rgtr' => t('Bus lines RGTR'),
            ],
            '#default_value' => $this->getSetting('layers'),
            '#description' => t('Layers to display on top of the base map.')
        ];
        $elements['zoom'] = [
            '#type' => 'number',
            '#title' => t('The starting zoom level.'),
            '#default_value' => $this->getSetting('zoom'),
        ];

        return $elements;
    }
    /**
     * {@inheritdoc}
     */
    public function settingsSummary()
    {
        $summary = [];
        $summary[] = t('Background layer: @bglayer', ['@bglayer' => $this->getSetting('bglayer')]);
        $summary[] = t('Overlay layer: @layers', ['@layers' => $this->getSetting('layers')]);
        $summary[] = t('Starting zoom: @zoom', ['@zoom' => $this->getSetting('zoom')]);

        return $summary;
    }
    /**
     * {@inheritdoc}
     */
    public function viewElements(FieldItemListInterface $items, $langcode)
    {
        $elements = [];

        foreach ($items as $delta => $item) {
            if ($item->isEmpty()) {
                continue;
            }
            $value = $item->getValue();
            if ($value['geo_type'] !== 'Point') {
                continue;
            }

            $locations[] = [$value['lat'],$value['lon']];

            $elements[$delta] = [
              '#theme' => 'geoportail_map',
//              '#bglayer' => $this->viewElements('bglayer'),
//            '#height' => $settings['height'],
//            '#scale' => $settings['scale'],
//            '#locations' => $locations,
//            '#zoom' => $settings['zoom'],
//                '#langcode' => $language,
//            '#static_map_type' => $settings['static_map_type'],
//            '#apikey' => (string) $this->getGmapApiKey(),
//            '#marker_color' => $settings['marker_color'],
//            '#marker_size' => $settings['marker_size'],
                '#attached' => [
                    'library' => [
                        'geoportail_map/geoportail_map_library',
                        'geoportail_map/geoportail_map_v3apiloader',
                    ],
                    'drupalSettings' => [
                        'geoportail_map' => [
                            'geoportail_map_library' => [
                                'locations' => $locations,
                                'bglayer' => $this->getSetting('bglayer'),
                                'zoom' => $this->getSetting('zoom'),
                                'layers' => $this->getSetting('layers')
                            ]
                        ],
                    ],
                ],
            ];
        }
//        var_dump($elements);
//        die();
        return $elements;
    }
}